@@ -1,6 +1,6 @@
 package Mojo::Webqq;
 use strict;
-$Mojo::Webqq::VERSION = "1.4.2";
+$Mojo::Webqq::VERSION = "1.4.3";
 use base qw(Mojo::Base);
 use Mojo::Webqq::Log;
 use Mojo::Webqq::Cache;
@@ -41,7 +41,7 @@ has log    => sub{Mojo::Webqq::Log->new(path=>$_[0]->log_path,level=>$_[0]->log_
     #$level .= " " if ($level eq "info" or $level eq "warn");
     @lines = split /\n/,join "",@lines;
     my $return;
-    my $time = POSIX::strftime('[%y/%m/%d %H:%M:%S]',localtime($time));
+    $time = POSIX::strftime('[%y/%m/%d %H:%M:%S]',localtime($time));
     for(@lines){
         $return .=
             $time
