@@ -31,8 +31,7 @@ sub update{
 
 sub send {
     my $self = shift;
-    my $content = shift;
-    $self->{_client}->send_message($self,$content);
+    $self->{_client}->send_message($self,@_);
 }
 
 1;
